#
# Autogenerated by Thrift Compiler (0.9.3)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
#  options string: py
#

from talos.thrift.Thrift import TType, TMessageType, TException, TApplicationException
from talos.thrift.auth.ttypes import *

SIGNATURE_SUPPORT = {
    1 : False,
    2 : True,
    10 : True,
    11 : True,
    12 : False,
    13 : False,
}
HK_HOST = "Host"
HK_TIMESTAMP = "X-Xiaomi-Timestamp"
MI_DATE = "x-xiaomi-date"
XIAOMI_HEADER_PREFIX = "x-xiaomi-"
HK_CONTENT_MD5 = "X-Xiaomi-Content-MD5"
HK_AUTHORIZATION = "Authorization"
HK_SERVICE_ADMIN = "Service-Admin"
HK_SERVICE_MARK = "#"
HK_ATTACHED_INFO = "Attached-Info"
SUGGESTED_SIGNATURE_HEADERS = [
  "Host",
  "X-Xiaomi-Timestamp",
  "X-Xiaomi-Content-MD5",
]
